# insteon-hub
An initial concept for a Python library for interfacing with the Insteon Hub2 Restful API http://docs.insteon.apiary.io/

This is mostly based off https://github.com/krkeegan/insteon-hub-python-lib which seems to be abandoned.

## Installation
Install instructions can be found here https://pypi.python.org/pypi/insteon_hub
